window.Gleam.initSearch([{"doc":"gleam_mongo","title":"gleam_mongo","content":"# gleam_mongo\n\nA mongodb driver for gleam\n\n## Quick start\n\n```sh\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\n```sh\ngleam add gleam_mongo\n```\n\n## Roadmap\n\n- [x] support basic mongodb commands\n- [x] support aggregation\n- [x] support connection strings\n- [x] support authentication\n- [x] support mongodb cursors\n- [ ] support connection pooling\n- [ ] support bulk operations\n- [ ] support transactions\n- [ ] support other mongodb commands\n- [ ] support tls\n- [ ] support clusters\n- [ ] support change streams\n\n## Usage\n\n```gleam\nimport gleam/uri\nimport gleam/option\nimport mongo\nimport mongo/cursor\nimport mongo/crud.{Sort, Upsert}\nimport mongo/aggregation.{Let, add_fields, aggregate, exec, match}\nimport bson/value\n\npub fn main() {\n  let encoded_password = uri.percent_encode(&quot;strong password&quot;)\n  let assert Ok(db) =\n    mongo.connect(\n      &quot;mongodb://app-dev:&quot; &lt;&gt; encoded_password &lt;&gt; &quot;@localhost/app-db?authSource=admin&quot;,\n    )\n\n  let users =\n    db\n    |&gt; mongo.collection(&quot;users&quot;)\n\n  let _ =\n    users\n    |&gt; mongo.insert_many([\n      value.Document([\n        #(&quot;username&quot;, value.Str(&quot;jmorrow&quot;)),\n        #(&quot;name&quot;, value.Str(&quot;vincent freeman&quot;)),\n        #(&quot;email&quot;, value.Str(&quot;jmorrow@gattaca.eu&quot;)),\n        #(&quot;age&quot;, value.Int32(32)),\n      ]),\n      value.Document([\n        #(&quot;username&quot;, value.Str(&quot;real-jerome&quot;)),\n        #(&quot;name&quot;, value.Str(&quot;jerome eugene morrow&quot;)),\n        #(&quot;email&quot;, value.Str(&quot;real-jerome@running.at&quot;)),\n        #(&quot;age&quot;, value.Int32(32)),\n      ]),\n    ])\n\n  let _ =\n    users\n    |&gt; mongo.update_one(\n      value.Document([#(&quot;username&quot;, value.Str(&quot;real-jerome&quot;))]),\n      value.Document([\n        #(\n          &quot;$set&quot;,\n          value.Document([\n            #(&quot;username&quot;, value.Str(&quot;eugene&quot;)),\n            #(&quot;email&quot;, value.Str(&quot;eugene@running.at &quot;)),\n          ]),\n        ),\n      ]),\n      [Upsert],\n    )\n\n  let assert Ok(yahoo_cursor) =\n    users\n    |&gt; mongo.find_many(\n      value.Document([#(&quot;email&quot;, value.Regex(#(&quot;yahoo&quot;, &quot;&quot;)))]),\n      [Sort(value.Document([#(&quot;username&quot;, value.Int32(-1))]))],\n    )\n  let _yahoo_users = cursor.to_list(yahoo_cursor)\n\n  let assert Ok(underage_lindsey_cursor) =\n    users\n    |&gt; aggregate([Let(value.Document([#(&quot;minimum_age&quot;, value.Int32(21))]))])\n    |&gt; match(value.Document([\n      #(\n        &quot;$expr&quot;,\n        value.Document([\n          #(&quot;$lt&quot;, value.Array([value.Str(&quot;$age&quot;), value.Str(&quot;$$minimum_age&quot;)])),\n        ]),\n      ),\n    ]))\n    |&gt; add_fields(value.Document([\n      #(\n        &quot;first_name&quot;,\n        value.Document([\n          #(\n            &quot;$arrayElemAt&quot;,\n            value.Array([\n              value.Document([\n                #(&quot;$split&quot;, value.Array([value.Str(&quot;$name&quot;), value.Str(&quot; &quot;)])),\n              ]),\n              value.Int32(0),\n            ]),\n          ),\n        ]),\n      ),\n    ]))\n    |&gt; match(value.Document([#(&quot;first_name&quot;, value.Str(&quot;lindsey&quot;))]))\n    |&gt; exec\n\n  let assert #(option.Some(_underage_lindsey), underage_lindsey_cursor) =\n    underage_lindsey_cursor\n    |&gt; cursor.next\n\n  let assert #(option.None, _) =\n    underage_lindsey_cursor\n    |&gt; cursor.next\n}\n```\n","url":"index.html"},{"doc":"mongo/utils","title":"MongoError","content":"pub type MongoError {\n  MongoError(code: Int, msg: String, source: value.Value)\n}\n\nMongoError(code: Int, msg: String, source: value.Value)\n\n\nSynonyms:\nmongo/utils.MongoError\nmongo/utils MongoError","url":"mongo/utils.html#MongoError"},{"doc":"mongo/utils","title":"default_error","content":"pub const default_error: MongoError = MongoError(\n  code: -16,\n  msg: &quot;&quot;,\n  source: value.Null,\n)\n\nSynonyms:\nmongo/utils.default_error\nmongo/utils default_error","url":"mongo/utils.html#default_error"},{"doc":"mongo/utils","title":"mongo/utils","content":"","url":"mongo/utils.html"},{"doc":"mongo/cursor","title":"Cursor","content":"pub opaque type Cursor\n\n\nSynonyms:\nmongo/cursor.Cursor\nmongo/cursor Cursor","url":"mongo/cursor.html#Cursor"},{"doc":"mongo/cursor","title":"new","content":"pub fn new(collection: Collection, id: Int, batch: List(Value)) -&gt; Cursor\n\nSynonyms:\nmongo/cursor.new\nmongo/cursor new","url":"mongo/cursor.html#new"},{"doc":"mongo/cursor","title":"next","content":"pub fn next(cursor: Cursor) -&gt; #(Option(Value), Cursor)\n\nSynonyms:\nmongo/cursor.next\nmongo/cursor next","url":"mongo/cursor.html#next"},{"doc":"mongo/cursor","title":"to_list","content":"pub fn to_list(cursor: Cursor) -&gt; List(Value)\n\nSynonyms:\nmongo/cursor.to_list\nmongo/cursor to_list","url":"mongo/cursor.html#to_list"},{"doc":"mongo/cursor","title":"mongo/cursor","content":"","url":"mongo/cursor.html"},{"doc":"mongo/aggregation","title":"AggregateOption","content":"pub type AggregateOption {\n  BatchSize(Int)\n  Let(value.Value)\n}\n\nBatchSize(Int)\n\n\nLet(value.Value)\n\n\nSynonyms:\nmongo/aggregation.AggregateOption\nmongo/aggregation AggregateOption","url":"mongo/aggregation.html#AggregateOption"},{"doc":"mongo/aggregation","title":"Pipeline","content":"pub opaque type Pipeline\n\n\nSynonyms:\nmongo/aggregation.Pipeline\nmongo/aggregation Pipeline","url":"mongo/aggregation.html#Pipeline"},{"doc":"mongo/aggregation","title":"add_fields","content":"pub fn add_fields(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.add_fields\nmongo/aggregation add_fields","url":"mongo/aggregation.html#add_fields"},{"doc":"mongo/aggregation","title":"aggregate","content":"pub fn aggregate(collection: Collection, options: List(\n    AggregateOption,\n  )) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.aggregate\nmongo/aggregation aggregate","url":"mongo/aggregation.html#aggregate"},{"doc":"mongo/aggregation","title":"exec","content":"pub fn exec(pipeline: Pipeline) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmongo/aggregation.exec\nmongo/aggregation exec","url":"mongo/aggregation.html#exec"},{"doc":"mongo/aggregation","title":"group","content":"pub fn group(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.group\nmongo/aggregation group","url":"mongo/aggregation.html#group"},{"doc":"mongo/aggregation","title":"limit","content":"pub fn limit(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.limit\nmongo/aggregation limit","url":"mongo/aggregation.html#limit"},{"doc":"mongo/aggregation","title":"lookup","content":"pub fn lookup(pipeline: Pipeline, from from: String, local_field local_field: String, foreign_field foreign_field: String, alias alias: String) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.lookup\nmongo/aggregation lookup","url":"mongo/aggregation.html#lookup"},{"doc":"mongo/aggregation","title":"match","content":"pub fn match(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.match\nmongo/aggregation match","url":"mongo/aggregation.html#match"},{"doc":"mongo/aggregation","title":"project","content":"pub fn project(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.project\nmongo/aggregation project","url":"mongo/aggregation.html#project"},{"doc":"mongo/aggregation","title":"skip","content":"pub fn skip(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.skip\nmongo/aggregation skip","url":"mongo/aggregation.html#skip"},{"doc":"mongo/aggregation","title":"sort","content":"pub fn sort(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.sort\nmongo/aggregation sort","url":"mongo/aggregation.html#sort"},{"doc":"mongo/aggregation","title":"stages","content":"pub fn stages(pipeline: Pipeline, docs: List(Value)) -&gt; Pipeline\n\nSynonyms:\nmongo/aggregation.stages\nmongo/aggregation stages","url":"mongo/aggregation.html#stages"},{"doc":"mongo/aggregation","title":"mongo/aggregation","content":"","url":"mongo/aggregation.html"},{"doc":"mongo/crud","title":"FindOption","content":"pub type FindOption {\n  Skip(Int)\n  Limit(Int)\n  BatchSize(Int)\n  Sort(value.Value)\n  Projection(value.Value)\n}\n\nSkip(Int)\n\n\nLimit(Int)\n\n\nBatchSize(Int)\n\n\nSort(value.Value)\n\n\nProjection(value.Value)\n\n\nSynonyms:\nmongo/crud.FindOption\nmongo/crud FindOption","url":"mongo/crud.html#FindOption"},{"doc":"mongo/crud","title":"InsertResult","content":"pub type InsertResult {\n  InsertResult(inserted: Int, inserted_ids: List(value.Value))\n}\n\nInsertResult(inserted: Int, inserted_ids: List(value.Value))\n\n\nSynonyms:\nmongo/crud.InsertResult\nmongo/crud InsertResult","url":"mongo/crud.html#InsertResult"},{"doc":"mongo/crud","title":"UpdateOption","content":"pub type UpdateOption {\n  Upsert\n  ArrayFilters(List(value.Value))\n}\n\nUpsert\n\n\nArrayFilters(List(value.Value))\n\n\nSynonyms:\nmongo/crud.UpdateOption\nmongo/crud UpdateOption","url":"mongo/crud.html#UpdateOption"},{"doc":"mongo/crud","title":"UpdateResult","content":"pub type UpdateResult {\n  UpdateResult(matched: Int, modified: Int)\n  UpsertResult(matched: Int, upserted_id: value.Value)\n}\n\nUpdateResult(matched: Int, modified: Int)\n\n\nUpsertResult(matched: Int, upserted_id: value.Value)\n\n\nSynonyms:\nmongo/crud.UpdateResult\nmongo/crud UpdateResult","url":"mongo/crud.html#UpdateResult"},{"doc":"mongo/crud","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.count\nmongo/crud count","url":"mongo/crud.html#count"},{"doc":"mongo/crud","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.count_all\nmongo/crud count_all","url":"mongo/crud.html#count_all"},{"doc":"mongo/crud","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.delete_many\nmongo/crud delete_many","url":"mongo/crud.html#delete_many"},{"doc":"mongo/crud","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.delete_one\nmongo/crud delete_one","url":"mongo/crud.html#delete_one"},{"doc":"mongo/crud","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  Cursor,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_all\nmongo/crud find_all","url":"mongo/crud.html#find_all"},{"doc":"mongo/crud","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_by_id\nmongo/crud find_by_id","url":"mongo/crud.html#find_by_id"},{"doc":"mongo/crud","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmongo/crud.find_many\nmongo/crud find_many","url":"mongo/crud.html#find_many"},{"doc":"mongo/crud","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.find_one\nmongo/crud find_one","url":"mongo/crud.html#find_one"},{"doc":"mongo/crud","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.insert_many\nmongo/crud insert_many","url":"mongo/crud.html#insert_many"},{"doc":"mongo/crud","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo/crud.insert_one\nmongo/crud insert_one","url":"mongo/crud.html#insert_one"},{"doc":"mongo/crud","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo/crud.update_many\nmongo/crud update_many","url":"mongo/crud.html#update_many"},{"doc":"mongo/crud","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo/crud.update_one\nmongo/crud update_one","url":"mongo/crud.html#update_one"},{"doc":"mongo/crud","title":"mongo/crud","content":"","url":"mongo/crud.html"},{"doc":"mongo","title":"collection","content":"pub fn collection(db: Database, name: String) -&gt; Collection\n\nSynonyms:\nmongo.collection\nmongo collection","url":"mongo.html#collection"},{"doc":"mongo","title":"connect","content":"pub fn connect(uri: String) -&gt; Result(Database, Nil)\n\nSynonyms:\nmongo.connect\nmongo connect","url":"mongo.html#connect"},{"doc":"mongo","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.count\nmongo count","url":"mongo.html#count"},{"doc":"mongo","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.count_all\nmongo count_all","url":"mongo.html#count_all"},{"doc":"mongo","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.delete_many\nmongo delete_many","url":"mongo.html#delete_many"},{"doc":"mongo","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmongo.delete_one\nmongo delete_one","url":"mongo.html#delete_one"},{"doc":"mongo","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  Cursor,\n  MongoError,\n)\n\nSynonyms:\nmongo.find_all\nmongo find_all","url":"mongo.html#find_all"},{"doc":"mongo","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo.find_by_id\nmongo find_by_id","url":"mongo.html#find_by_id"},{"doc":"mongo","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmongo.find_many\nmongo find_many","url":"mongo.html#find_many"},{"doc":"mongo","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmongo.find_one\nmongo find_one","url":"mongo.html#find_one"},{"doc":"mongo","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmongo.insert_many\nmongo insert_many","url":"mongo.html#insert_many"},{"doc":"mongo","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmongo.insert_one\nmongo insert_one","url":"mongo.html#insert_one"},{"doc":"mongo","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo.update_many\nmongo update_many","url":"mongo.html#update_many"},{"doc":"mongo","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmongo.update_one\nmongo update_one","url":"mongo.html#update_one"},{"doc":"mongo","title":"mongo","content":"","url":"mongo.html"}]);